@@ -29,6 +29,9 @@
 #include <QtConcurrent/QtConcurrentRun>
 #include <QtConcurrent>
 
+#include <QClipboard>
+#include <QGuiApplication>
+
 FMList::FMList(QObject *parent)
     : MauiList(parent)
     , fm(new FM(this))
@@ -120,7 +123,6 @@ FMList::FMList(QObject *parent)
                 this->refresh();
             }
         }
-
     });
     
     connect(Tagging::getInstance(), &Tagging::tagged, [this](QVariantMap)
@@ -435,6 +437,9 @@ void FMList::refresh()
 
 void FMList::createDir(const QString &name)
 {
+    if(m_readOnly)
+        return;
+    
     if (this->pathType == FMList::PATHTYPE::CLOUD_PATH) {
 #ifdef COMPONENT_SYNCING
         this->fm->createCloudDir(QString(this->path.toString()).replace(FMStatic::PATHTYPE_SCHEME[FMStatic::PATHTYPE_KEY::CLOUD_PATH] + "/" + this->fm->sync->getUser(), ""), name);
@@ -444,13 +449,152 @@ void FMList::createDir(const QString &name)
     }
 }
 
+void FMList::createFile(const QString& name)
+{
+    if(m_readOnly)
+        return;
+    
+     FMStatic::createFile(this->path, name);
+}
+
+void FMList::renameFile(const QString& url, const QString& newName)
+{
+    if(m_readOnly)
+        return;
+    
+    FMStatic::rename(url, newName);
+}
+
+void FMList::moveToTrash(const QStringList& urls)
+{
+    if(m_readOnly)
+        return;
+    
+    FMStatic::moveToTrash(QUrl::fromStringList(urls));
+}
+
+void FMList::removeFiles(const QStringList& urls)
+{
+    if(m_readOnly)
+        return;
+    
+    FMStatic::removeFiles(QUrl::fromStringList(urls));
+}
+
+void FMList::createSymlink(const QString& url)
+{
+    if(m_readOnly)
+        return;
+    
+    FMStatic::createSymlink(url, this->path);
+}
+
+bool FMList::saveImageFile(const QImage& image)
+{
+    QString fileName = QString("%1/pasted_image-0.%2").arg(path.toLocalFile(), "png");
+   
+    int idx = 1;
+    while ( QFile::exists( fileName ) )
+    {
+        fileName = QString("%1/pasted_image-%2.%3").arg(path.toLocalFile(), QString::number(idx), "png");
+        idx++;
+    }    
+    
+    return image.save(fileName);
+}
+
+bool FMList::saveTextFile(const QString& data, const QString &format)
+{
+    QString fileName = QString("%1/pasted_text-0.%2").arg(path.toLocalFile(), format);
+       
+    int idx = 1;
+    while ( QFile::exists( fileName ) )
+    {
+        fileName = QString("%1/pasted_text-%2.%3").arg(path.toLocalFile(), QString::number(idx), format);
+        idx++;
+    }   
+    
+    QFile file(fileName);
+    
+        if (file.open(QIODevice::ReadWrite)) 
+        {
+            QTextStream out(&file);
+            out << data;    
+            file.close(); 
+            return true;
+        }
+   
+   return false;
+}
+
+void FMList::paste()
+{  
+    if(m_readOnly)
+        return;
+    
+    const QClipboard *clipboard = QGuiApplication::clipboard();
+    const QMimeData *mimeData = clipboard->mimeData();
+    
+    if(!mimeData)
+    {
+        qWarning() << "Could not get mime data from the clipboard";
+         return;  
+    }  
+    
+    if (mimeData->hasImage()) 
+    {
+        saveImageFile(qvariant_cast<QImage>(mimeData->imageData()));
+    } else if (mimeData->hasUrls())
+    {
+        const QByteArray a = mimeData->data(QStringLiteral("application/x-kde-cutselection"));        
+        const bool cut =  (!a.isEmpty() && a.at(0) == '1');
+       
+       if(cut)
+       {
+           cutInto(QUrl::toStringList(mimeData->urls()));
+           // mimeData->clear();
+    }else
+    {
+        copyInto(QUrl::toStringList(mimeData->urls()));
+    }       
+       
+    } else if (mimeData->hasText()) 
+    {
+        saveTextFile(mimeData->text(), "txt");
+    } else 
+    {
+        qWarning() << "Unexpected mime type from clipboard content for performing a paste";
+    }    
+}
+
+bool FMList::clipboardHasContent() const
+{
+    const QClipboard *clipboard = QGuiApplication::clipboard();
+    const QMimeData *mimeData = clipboard->mimeData();
+    
+    if(!mimeData)
+    {
+        qWarning() << "Could not get mime data from the clipboard";
+        return false;  
+    }  
+    
+    return mimeData->hasUrls() || mimeData->hasImage() || mimeData->hasText();
+}
+
+
 void FMList::copyInto(const QStringList &urls)
 {
+    if(m_readOnly)
+        return;
+    
     this->fm->copy(QUrl::fromStringList(urls), this->path);
 }
 
 void FMList::cutInto(const QStringList &urls)
 {
+    if(m_readOnly)
+        return;
+    
     this->fm->cut(QUrl::fromStringList(urls), this->path);  
 }
 
@@ -676,5 +820,18 @@ void FMList::setAutoLoad(bool value)
     Q_EMIT autoLoadChanged();
 }
 
+bool FMList::readOnly() const
+{
+    return m_readOnly;
+}
+
+void FMList::setReadOnly(bool value)
+{
+    if(m_readOnly == value)
+        return;
+    
+    m_readOnly = value;
+    Q_EMIT readOnlyChanged();
+}
 
 
